aboutsummaryrefslogtreecommitdiffstats
path: root/core/types
diff options
context:
space:
mode:
authorJimmy Hu <jimmy.hu@dexon.org>2018-08-16 10:22:54 +0800
committerGitHub <noreply@github.com>2018-08-16 10:22:54 +0800
commit96fcee4688dacd812292376994a3500e2c78edeb (patch)
tree2e15153e47b9d75bce11e35d47ad265466856afa /core/types
parentd3107b56cbef1f05baddb64880c3e97d7eda87a4 (diff)
downloaddexon-consensus-96fcee4688dacd812292376994a3500e2c78edeb.tar
dexon-consensus-96fcee4688dacd812292376994a3500e2c78edeb.tar.gz
dexon-consensus-96fcee4688dacd812292376994a3500e2c78edeb.tar.bz2
dexon-consensus-96fcee4688dacd812292376994a3500e2c78edeb.tar.lz
dexon-consensus-96fcee4688dacd812292376994a3500e2c78edeb.tar.xz
dexon-consensus-96fcee4688dacd812292376994a3500e2c78edeb.tar.zst
dexon-consensus-96fcee4688dacd812292376994a3500e2c78edeb.zip
core: Add compaction chain module. (#60)
Diffstat (limited to 'core/types')
-rw-r--r--core/types/block.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/types/block.go b/core/types/block.go
index 15fae8b..0fa16d4 100644
--- a/core/types/block.go
+++ b/core/types/block.go
@@ -40,9 +40,9 @@ const (
// CompactionChainAck represents the acking to the compaction chain.
type CompactionChainAck struct {
AckingBlockHash common.Hash `json:"acking_block_hash"`
// Signature is the signature of the hash value of
// Block.ConsensusInfoParentHash and Block.ConsensusInfo.
- ConsensusSignature crypto.Signature `json:"consensus_signature"`
+ ConsensusInfoSignature crypto.Signature `json:"consensus_info_signature"`
}
// ConsensusInfo represents the consensus information on the compaction chain.
@@ -120,8 +120,8 @@ func (b *Block) Clone() *Block {
},
ConsensusInfoParentHash: b.ConsensusInfoParentHash,
}
- bcopy.CompactionChainAck.ConsensusSignature = append(
- crypto.Signature(nil), b.CompactionChainAck.ConsensusSignature...)
+ bcopy.CompactionChainAck.ConsensusInfoSignature = append(
+ crypto.Signature(nil), b.CompactionChainAck.ConsensusInfoSignature...)
for k, v := range b.Timestamps {
bcopy.Timestamps[k] = v
}
@@ -40,9 +40,9 @@ const (
type CompactionChainAck struct {
AckingBlockHash common.Hash `json:"acking_block_hash"`
- // Signature is the signature of the hash value of
+ // ConsensusInfoSignature is the signature of the hash value of
// Block.ConsensusInfoParentHash and Block.ConsensusInfo.